package com.care.client.service;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.care.client.vo.DeviceMonitorVO;
import com.care.client.vo.HouseContactVO;
import com.care.common.entity.CareHouseContact;
import com.care.common.entity.CareMemberInfo;
import com.care.common.service.CareDeviceService;
import com.care.common.service.CareHouseContactService;
import com.care.common.service.CareMemberInfoService;
import com.care.common.vo.device.DeviceVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.compress.utils.Lists;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author: lilt
 * @Date: 2021/6/7
 * @Desc:
 */
@Slf4j
@Service
public class PinanbaoService {
    @Resource
    private CareDeviceService careDeviceService;
    @Resource
    private CareMemberInfoService careMemberInfoService;
    @Resource
    private CareHouseContactService careHouseContactService;

    /**
     * 查询房屋的设备列表
     * @param memberId
     * @return
     */
    public List<DeviceVO> devList(Long memberId){
        CareMemberInfo memberInfo = this.careMemberInfoService.getById(memberId);
        return this.careDeviceService.queryListByHouseId(memberInfo.getHouseId());
    }

    /**
     * 设备监测数据
     * @param devId
     * @return
     */
    public DeviceMonitorVO devMonitorData(Long devId){
        //TODO 获取监测数据，从redis中获取
        DeviceMonitorVO vo = new DeviceMonitorVO();
        vo.setId(devId);
        vo.setBreathRate(30);
        vo.setHeartRate(60);
        vo.setActivityDistance(600);
        vo.setActivityTimeHour(1);
        vo.setActivityTimeMinute(20);
        vo.setSleepTimeHour(8);
        vo.setSleepTimeMinute(7);
        return vo;
    }

    /**
     * 查询房屋紧急联系人
     * @param memberId
     * @return
     */
    public List<HouseContactVO> queryContactByMemberId(Long memberId){
        List<HouseContactVO> vos = Lists.newArrayList();
        CareMemberInfo memberInfo = this.careMemberInfoService.getById(memberId);
        QueryWrapper<CareHouseContact> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(CareHouseContact::getHouseId, memberInfo.getHouseId())
        .orderByAsc(CareHouseContact::getContactLevel);
        List<CareHouseContact> contacts = this.careHouseContactService.list(queryWrapper);
        if (CollUtil.isNotEmpty(contacts)){
            contacts.forEach(item -> {
                HouseContactVO vo = new HouseContactVO();
                BeanUtil.copyProperties(item,vo);
                vos.add(vo);
            });
        }
        return vos;
    }
}
